@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -51,6 +53,8 @@ class AmsDetailInfo(AbstractModel):
         :type DetailCount: int
         :param RequestId: 音频审核的请求 id
         :type RequestId: str
+        :param Status: 音频机审状态
+        :type Status: str
         """
         self.Label = None
         self.Duration = None
@@ -66,6 +70,7 @@ class AmsDetailInfo(AbstractModel):
         self.Content = None
         self.DetailCount = None
         self.RequestId = None
+        self.Status = None
 
 
     def _deserialize(self, params):
@@ -83,6 +88,14 @@ class AmsDetailInfo(AbstractModel):
         self.Content = params.get("Content")
         self.DetailCount = params.get("DetailCount")
         self.RequestId = params.get("RequestId")
+        self.Status = params.get("Status")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class AudioResult(AbstractModel):
@@ -165,6 +178,13 @@ class AudioResult(AbstractModel):
                 obj = AudioResultDetailLanguageResult()
                 obj._deserialize(item)
                 self.LanguageResults.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class AudioResultDetailLanguageResult(AbstractModel):
@@ -203,6 +223,13 @@ class AudioResultDetailLanguageResult(AbstractModel):
         self.StartTime = params.get("StartTime")
         self.EndTime = params.get("EndTime")
         self.SubLabelCode = params.get("SubLabelCode")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class AudioResultDetailMoanResult(AbstractModel):
@@ -237,6 +264,13 @@ class AudioResultDetailMoanResult(AbstractModel):
         self.StartTime = params.get("StartTime")
         self.EndTime = params.get("EndTime")
         self.SubLabelCode = params.get("SubLabelCode")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class AudioResultDetailTextResult(AbstractModel):
@@ -284,6 +318,13 @@ class AudioResultDetailTextResult(AbstractModel):
         self.Score = params.get("Score")
         self.Suggestion = params.get("Suggestion")
         self.LibType = params.get("LibType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class AudioSegments(AbstractModel):
@@ -311,6 +352,13 @@ class AudioSegments(AbstractModel):
         if params.get("Result") is not None:
             self.Result = AudioResult()
             self.Result._deserialize(params.get("Result"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class BucketInfo(AbstractModel):
@@ -337,6 +385,13 @@ class BucketInfo(AbstractModel):
         self.Bucket = params.get("Bucket")
         self.Region = params.get("Region")
         self.Object = params.get("Object")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CancelTaskRequest(AbstractModel):
@@ -354,6 +409,13 @@ class CancelTaskRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.TaskId = params.get("TaskId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CancelTaskResponse(AbstractModel):
@@ -371,6 +433,13 @@ class CancelTaskResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateAudioModerationTaskRequest(AbstractModel):
@@ -409,6 +478,13 @@ class CreateAudioModerationTaskRequest(AbstractModel):
                 obj = TaskInput()
                 obj._deserialize(item)
                 self.Tasks.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateAudioModerationTaskResponse(AbstractModel):
@@ -436,6 +512,13 @@ class CreateAudioModerationTaskResponse(AbstractModel):
                 obj._deserialize(item)
                 self.Results.append(obj)
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateBizConfigRequest(AbstractModel):
@@ -467,6 +550,13 @@ class CreateBizConfigRequest(AbstractModel):
             self.MediaModeration._deserialize(params.get("MediaModeration"))
         self.BizName = params.get("BizName")
         self.ModerationCategories = params.get("ModerationCategories")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class CreateBizConfigResponse(AbstractModel):
@@ -484,6 +574,13 @@ class CreateBizConfigResponse(AbstractModel):
 
     def _deserialize(self, params):
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAmsListRequest(AbstractModel):
@@ -518,6 +615,13 @@ class DescribeAmsListRequest(AbstractModel):
                 obj = Filter()
                 obj._deserialize(item)
                 self.Filters.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAmsListResponse(AbstractModel):
@@ -552,6 +656,13 @@ class DescribeAmsListResponse(AbstractModel):
         self.Total = params.get("Total")
         self.PageToken = params.get("PageToken")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAudioStatRequest(AbstractModel):
@@ -578,6 +689,13 @@ class DescribeAudioStatRequest(AbstractModel):
                 obj = Filters()
                 obj._deserialize(item)
                 self.Filters.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeAudioStatResponse(AbstractModel):
@@ -619,6 +737,13 @@ class DescribeAudioStatResponse(AbstractModel):
                 obj._deserialize(item)
                 self.EvilCount.append(obj)
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeBizConfigRequest(AbstractModel):
@@ -636,6 +761,13 @@ class DescribeBizConfigRequest(AbstractModel):
 
     def _deserialize(self, params):
         self.BizType = params.get("BizType")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeBizConfigResponse(AbstractModel):
@@ -681,6 +813,13 @@ class DescribeBizConfigResponse(AbstractModel):
         self.CreatedAt = params.get("CreatedAt")
         self.UpdatedAt = params.get("UpdatedAt")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeTaskDetailRequest(AbstractModel):
@@ -702,6 +841,13 @@ class DescribeTaskDetailRequest(AbstractModel):
     def _deserialize(self, params):
         self.TaskId = params.get("TaskId")
         self.ShowAllSegments = params.get("ShowAllSegments")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class DescribeTaskDetailResponse(AbstractModel):
@@ -828,6 +974,13 @@ Block 建议屏蔽；
                 self.ImageSegments.append(obj)
         self.AudioText = params.get("AudioText")
         self.RequestId = params.get("RequestId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class EvilCount(AbstractModel):
@@ -849,6 +1002,13 @@ class EvilCount(AbstractModel):
     def _deserialize(self, params):
         self.EvilType = params.get("EvilType")
         self.Count = params.get("Count")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class FileOutput(AbstractModel):
@@ -874,6 +1034,13 @@ class FileOutput(AbstractModel):
         self.Bucket = params.get("Bucket")
         self.Region = params.get("Region")
         self.ObjectPrefix = params.get("ObjectPrefix")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class Filter(AbstractModel):
@@ -895,6 +1062,13 @@ class Filter(AbstractModel):
     def _deserialize(self, params):
         self.Name = params.get("Name")
         self.Values = params.get("Values")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class Filters(AbstractModel):
@@ -919,6 +1093,13 @@ class Filters(AbstractModel):
     def _deserialize(self, params):
         self.Name = params.get("Name")
         self.Values = params.get("Values")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ImageResult(AbstractModel):
@@ -971,6 +1152,13 @@ class ImageResult(AbstractModel):
                 self.Results.append(obj)
         self.Url = params.get("Url")
         self.Extra = params.get("Extra")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ImageResultResult(AbstractModel):
@@ -1040,6 +1228,13 @@ Ad 广告
                 obj = ImageResultsResultDetail()
                 obj._deserialize(item)
                 self.Details.append(obj)
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ImageResultsResultDetail(AbstractModel):
@@ -1107,6 +1302,13 @@ class ImageResultsResultDetail(AbstractModel):
         self.Suggestion = params.get("Suggestion")
         self.Score = params.get("Score")
         self.SubLabelCode = params.get("SubLabelCode")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ImageResultsResultDetailLocation(AbstractModel):
@@ -1145,6 +1347,13 @@ class ImageResultsResultDetailLocation(AbstractModel):
         self.Width = params.get("Width")
         self.Height = params.get("Height")
         self.Rotate = params.get("Rotate")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class ImageSegments(AbstractModel):
@@ -1170,6 +1379,13 @@ class ImageSegments(AbstractModel):
             self.Result = ImageResult()
             self.Result._deserialize(params.get("Result"))
         self.OffsetTime = params.get("OffsetTime")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class InputInfo(AbstractModel):
@@ -1200,6 +1416,13 @@ class InputInfo(AbstractModel):
         if params.get("BucketInfo") is not None:
             self.BucketInfo = BucketInfo()
             self.BucketInfo._deserialize(params.get("BucketInfo"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class MediaInfo(AbstractModel):
@@ -1234,6 +1457,13 @@ class MediaInfo(AbstractModel):
         self.Width = params.get("Width")
         self.Height = params.get("Height")
         self.Thumbnail = params.get("Thumbnail")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class MediaModerationConfig(AbstractModel):
@@ -1273,6 +1503,13 @@ class MediaModerationConfig(AbstractModel):
             self.SegmentOutput._deserialize(params.get("SegmentOutput"))
         self.UseOCR = params.get("UseOCR")
         self.UseAudio = params.get("UseAudio")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class Overview(AbstractModel):
@@ -1318,6 +1555,13 @@ class Overview(AbstractModel):
         self.EvilHour = params.get("EvilHour")
         self.SuspectCount = params.get("SuspectCount")
         self.SuspectHour = params.get("SuspectHour")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class StorageInfo(AbstractModel):
@@ -1347,6 +1591,13 @@ COS 腾讯云对象存储类型
         if params.get("BucketInfo") is not None:
             self.BucketInfo = BucketInfo()
             self.BucketInfo._deserialize(params.get("BucketInfo"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class TaskInput(AbstractModel):
@@ -1374,6 +1625,13 @@ class TaskInput(AbstractModel):
         if params.get("Input") is not None:
             self.Input = StorageInfo()
             self.Input._deserialize(params.get("Input"))
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class TaskLabel(AbstractModel):
@@ -1404,6 +1662,13 @@ class TaskLabel(AbstractModel):
         self.Label = params.get("Label")
         self.Suggestion = params.get("Suggestion")
         self.Score = params.get("Score")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class TaskResult(AbstractModel):
@@ -1437,6 +1702,13 @@ class TaskResult(AbstractModel):
         self.TaskId = params.get("TaskId")
         self.Code = params.get("Code")
         self.Message = params.get("Message")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
 
 
 class TrendCount(AbstractModel):
@@ -1485,4 +1757,11 @@ class TrendCount(AbstractModel):
         self.EvilHour = params.get("EvilHour")
         self.SuspectCount = params.get("SuspectCount")
         self.SuspectHour = params.get("SuspectHour")
-        self.Date = params.get("Date")
\ No newline at end of file
+        self.Date = params.get("Date")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set), Warning)
+        
\ No newline at end of file
